@@ -24,8 +24,11 @@
 #ifndef _transform_factory_h_
 #define _transform_factory_h_
 
+#include "common.h"
+
 class Random01;
-class Transform;
+
+#include "transform.h"
 
 //! Abstract base class for classes creating Transforms
 class TransformFactory 
@@ -37,7 +40,7 @@ class TransformFactory
     {}
 
   //! Clone functionality needed to retain typed copies of factories.
-  virtual std::auto_ptr<TransformFactory> clone() const
+  virtual std::unique_ptr<TransformFactory> clone() const
     =0;
 
   //! Method to build a Transform.
@@ -60,9 +63,9 @@ class TransformFactoryRandomWarpXY : public TransformFactory
     {}
 
   //! Clone.
-  virtual std::auto_ptr<TransformFactory> clone() const
+  virtual std::unique_ptr<TransformFactory> clone() const
     {
-      return std::auto_ptr<TransformFactory>(new TransformFactoryRandomWarpXY());
+      return std::unique_ptr<TransformFactory>(new TransformFactoryRandomWarpXY());
     }
 
   //! Return a random transform.
@@ -81,9 +84,9 @@ class TransformFactoryRandomScaleXY : public TransformFactory
     {}
 
   //! Clone method.
-  virtual std::auto_ptr<TransformFactory> clone() const
+  virtual std::unique_ptr<TransformFactory> clone() const
     {
-      return std::auto_ptr<TransformFactory>(new TransformFactoryRandomScaleXY(_lopow2,_hipow2));
+      return std::unique_ptr<TransformFactory>(new TransformFactoryRandomScaleXY(_lopow2,_hipow2));
     }
 
   //! Return a random scaling transform.
@@ -105,9 +108,9 @@ class TransformFactoryRandomRotateZ : public TransformFactory
     {}
 
   //! Clone method.
-  virtual std::auto_ptr<TransformFactory> clone() const
+  virtual std::unique_ptr<TransformFactory> clone() const
     {
-      return std::auto_ptr<TransformFactory>(new TransformFactoryRandomRotateZ());
+      return std::unique_ptr<TransformFactory>(new TransformFactoryRandomRotateZ());
     }
 
   //! Create a transform.
@@ -126,9 +129,9 @@ class TransformFactoryRandomTranslateXYZ : public TransformFactory
     {}
 
   //! Clone method.
-  virtual std::auto_ptr<TransformFactory> clone() const
+  virtual std::unique_ptr<TransformFactory> clone() const
     {
-      return std::auto_ptr<TransformFactory>(new TransformFactoryRandomTranslateXYZ(_origin,_range));
+      return std::unique_ptr<TransformFactory>(new TransformFactoryRandomTranslateXYZ(_origin,_range));
     }
 
   //! Return a random Transform
