@@ -92,8 +92,8 @@
 "<p>\n"
 "  <ul><li>-m, --multisample <i>multisample grid</i> <br>\n"
 "  Enables additional antialiasing passes. \n"
-"  Specifing 2 or 3 will provide an additional pass with 2x2 or 3x3 samples per pixel. \n"
-"  Specifiying 4 (of higher) will provide a 2x2 and a final 4x4 pass. \n"
+"  Specifying 2 or 3 will provide an additional pass with 2x2 or 3x3 samples per pixel. \n"
+"  Specifying 4 (or higher) will provide a 2x2 and a final 4x4 pass. \n"
 "  Specifying 1 provides the default behaviour of one sample per pixel. \n"
 "  For best rendering quality also specify -j. \n"
 "</li>\n"
@@ -476,7 +476,7 @@
 "  The &quot;randomize function weights&quot; version of restart scrambles \n"
 "  the relative probability of the various function types (if you \n"
 "  think evolvotron just keeps generating the same kinds of \n"
-"  images give it a try). The &quot;restart with specifc function&quot; \n"
+"  images give it a try). The &quot;restart with specific function&quot; \n"
 "  item duplicates the functionality of the &quot;-x&quot; and &quot;-X&quot; command-line \n"
 "  options. \n"
 "  </li><li>Edit menu: \n"
@@ -493,7 +493,7 @@
 "  &quot;Functions&quot; brings up a dialog to modify the relative probability \n"
 "  of functions being used. By default all functions are equally \n"
 "  likely except for iterative functions and fractals, which are \n"
-"  almost but not completely supressed. But if you think there \n"
+"  almost but not completely suppressed. But if you think there \n"
 "  are too many spirals or grids (or not enough fractals) then this \n"
 "  is the place to adjust the frequency with which they appear. \n"
 "  If the software was built with the fullscreen option, \n"
@@ -612,7 +612,7 @@
 "</p>\n"
 "<p>\n"
 "  There are two kinds of mutation: perturbations to the magnitude of constants, \n"
-"  and structural mutations which rearrage the function tree of an image. \n"
+"  and structural mutations which re-arrange the function tree of an image. \n"
 "  Four types of structural mutations are currently implemented: \n"
 "  <ul><li>replacement of a function branch by a new random stub (a &quot;Glitch&quot; mutation). \n"
 "  </li><li>a random shuffle of a node's sub-nodes \n"
@@ -632,7 +632,7 @@
 "  being a thermal effect (hence the &quot;heat&quot; and &quot;cool&quot; buttons), while \n"
 "  structural alterations are more drastic and are caused by high energy \n"
 "  gamma rays or something (hence &quot;irradiate&quot; and &quot;shield&quot; buttons to \n"
-"  adjust the probability of structual mutations). \n"
+"  adjust the probability of structural mutations). \n"
 "</p>\n"
 "<p>\n"
 "  So why would you want to change the mutation parameters from the initial \n"
@@ -673,7 +673,7 @@
 "<p>\n"
 "  3 types of function node are considered fundamental: constant nodes \n"
 "  (which return a constant), identity nodes (which return their \n"
-"  position argument) and transform nodes (which transform their positon \n"
+"  position argument) and transform nodes (which transform their position \n"
 "  argument by random parameters). On the &quot;Dilution&quot; tab of the &quot;Functions&quot; \n"
 "  dialog there are two slider controls to affect things related to these: \n"
 "  <ul><li>&quot;proportion constant&quot; controls the proportion of diluting fundamental nodes \n"
@@ -741,6 +741,7 @@
 "  </li><li>Massimiliano Guastafierro \n"
 "  </li><li>Goetz Waschk \n"
 "  </li><li>Forrest Walter \n"
+"  </li><li>&quot;chr_bl&quot; at web.de \n"
 "</li>\n"
 "</ul>\n"
 "</p>\n"
