@@ -25,6 +25,8 @@
 #ifndef _function_boilerplate_h_
 #define _function_boilerplate_h_
 
+#include "common.h"
+
 #include "function_node.h"
 #include "function_node_info.h"
 #include "function_registry.h"
@@ -58,18 +60,18 @@ template <typename FUNCTION,uint PARAMETERS,uint ARGUMENTS,bool ITERATIVE,uint C
   virtual uint self_classification() const;
 
   //! Factory method to create a stub node for this type
-  static std::auto_ptr<FunctionNode> stubnew(const MutationParameters& mutation_parameters,bool exciting);
+  static std::unique_ptr<FunctionNode> stubnew(const MutationParameters& mutation_parameters,bool exciting);
 
   //! Factory method to create a node given contents.
   /*! Returns null if there's a problem, in which case explanation is in report
    */
-  static std::auto_ptr<FunctionNode> create(const FunctionRegistry& function_registry,const FunctionNodeInfo& info,std::string& report);
+  static std::unique_ptr<FunctionNode> create(const FunctionRegistry& function_registry,const FunctionNodeInfo& info,std::string& report);
 
   //! Return a deeploned copy.
-  virtual std::auto_ptr<FunctionNode> deepclone() const;
+  virtual std::unique_ptr<FunctionNode> deepclone() const;
 
   //! Return a deeploned copy with more specific type (but of course this can't be virtual).
-  std::auto_ptr<FUNCTION> typed_deepclone() const;
+  std::unique_ptr<FUNCTION> typed_deepclone() const;
     
   //! Internal self-consistency check.  We can add some extra checks.
   virtual bool ok() const;
@@ -114,15 +116,18 @@ uint FunctionBoilerplate<FUNCTION,PARAMETERS,ARGUMENTS,ITERATIVE,CLASSIFICATION>
 }
 
 template <typename FUNCTION,uint PARAMETERS,uint ARGUMENTS,bool ITERATIVE,uint CLASSIFICATION>
-std::auto_ptr<FunctionNode> FunctionBoilerplate<FUNCTION,PARAMETERS,ARGUMENTS,ITERATIVE,CLASSIFICATION>::stubnew(const MutationParameters& mutation_parameters,bool exciting)
+std::unique_ptr<FunctionNode> FunctionBoilerplate<FUNCTION,PARAMETERS,ARGUMENTS,ITERATIVE,CLASSIFICATION>::stubnew(const MutationParameters& mutation_parameters,bool exciting)
 {
+  static constexpr uint _PARAMETERS=PARAMETERS;
+  static constexpr uint _ARGUMENTS=ARGUMENTS;
+  
   std::vector<real> params;
-  stubparams(params,mutation_parameters,PARAMETERS);
+  stubparams(params,mutation_parameters,_PARAMETERS);
   
   boost::ptr_vector<FunctionNode> args;
-  stubargs(args,mutation_parameters,ARGUMENTS,exciting);
+  stubargs(args,mutation_parameters,_ARGUMENTS,exciting);
   
-  return std::auto_ptr<FunctionNode>
+  return std::unique_ptr<FunctionNode>
     (
      new FUNCTION
      (
@@ -134,26 +139,26 @@ std::auto_ptr<FunctionNode> FunctionBoilerplate<FUNCTION,PARAMETERS,ARGUMENTS,IT
 }
 
 template <typename FUNCTION,uint PARAMETERS,uint ARGUMENTS,bool ITERATIVE,uint CLASSIFICATION>
-std::auto_ptr<FunctionNode> FunctionBoilerplate<FUNCTION,PARAMETERS,ARGUMENTS,ITERATIVE,CLASSIFICATION>::create(const FunctionRegistry& function_registry,const FunctionNodeInfo& info,std::string& report)
+std::unique_ptr<FunctionNode> FunctionBoilerplate<FUNCTION,PARAMETERS,ARGUMENTS,ITERATIVE,CLASSIFICATION>::create(const FunctionRegistry& function_registry,const FunctionNodeInfo& info,std::string& report)
 {
-  if (!verify_info(info,PARAMETERS,ARGUMENTS,ITERATIVE,report)) return std::auto_ptr<FunctionNode>();
+  if (!verify_info(info,PARAMETERS,ARGUMENTS,ITERATIVE,report)) return std::unique_ptr<FunctionNode>();
   
   boost::ptr_vector<FunctionNode> args;
-  if (!create_args(function_registry,info,args,report)) return std::auto_ptr<FunctionNode>();
+  if (!create_args(function_registry,info,args,report)) return std::unique_ptr<FunctionNode>();
   
-  return std::auto_ptr<FunctionNode>(new FUNCTION(info.params(),args,info.iterations()));
+  return std::unique_ptr<FunctionNode>(new FUNCTION(info.params(),args,info.iterations()));
 }
 
 template <typename FUNCTION,uint PARAMETERS,uint ARGUMENTS,bool ITERATIVE,uint CLASSIFICATION>
-std::auto_ptr<FunctionNode> FunctionBoilerplate<FUNCTION,PARAMETERS,ARGUMENTS,ITERATIVE,CLASSIFICATION>::deepclone() const
+std::unique_ptr<FunctionNode> FunctionBoilerplate<FUNCTION,PARAMETERS,ARGUMENTS,ITERATIVE,CLASSIFICATION>::deepclone() const
 {
-  return std::auto_ptr<FunctionNode>(typed_deepclone());
+  return std::unique_ptr<FunctionNode>(typed_deepclone());
 }
 
 template <typename FUNCTION,uint PARAMETERS,uint ARGUMENTS,bool ITERATIVE,uint CLASSIFICATION>
-std::auto_ptr<FUNCTION> FunctionBoilerplate<FUNCTION,PARAMETERS,ARGUMENTS,ITERATIVE,CLASSIFICATION>::typed_deepclone() const
+std::unique_ptr<FUNCTION> FunctionBoilerplate<FUNCTION,PARAMETERS,ARGUMENTS,ITERATIVE,CLASSIFICATION>::typed_deepclone() const
 {
-  return std::auto_ptr<FUNCTION>(new FUNCTION(cloneparams(),*cloneargs(),iterations()));
+  return std::unique_ptr<FUNCTION>(new FUNCTION(cloneparams(),*cloneargs(),iterations()));
 }
 
 template <typename FUNCTION,uint PARAMETERS,uint ARGUMENTS,bool ITERATIVE,uint CLASSIFICATION>
@@ -204,6 +209,10 @@ std::ostream& FunctionBoilerplate<FUNCTION,PARAMETERS,ARGUMENTS,ITERATIVE,CLASSI
 #define REGISTER_DCL(FN) extern void register_ ## FN(FunctionRegistry&);
 #define REGISTER_IMP(FN) void register_ ## FN(FunctionRegistry& r){REGISTER(r,FN);}
 
+#ifdef FUNCTION_BOILERPLATE_INSTANTIATE
+#define FUNCTION_END(FN) };FN_CTOR_IMP(FN);FN_DTOR_IMP(FN);FN_VNAME_IMP(FN);FN_SNAME_IMP(FN);REGISTER_IMP(FN);
+#else
 #define FUNCTION_END(FN) };REGISTER_DCL(FN);
+#endif
 
 #endif
