@@ -24,6 +24,10 @@
 #ifndef _function_compose_pair_h_
 #define _function_compose_pair_h_
 
+#include "common.h"
+
+#include "function_boilerplate.h"
+
 FUNCTION_BEGIN(FunctionComposePair,0,2,false,0)
 
   //! Evaluate function.
