@@ -24,6 +24,10 @@
 #ifndef _function_compose_triple_h_
 #define _function_compose_triple_h_
 
+#include "common.h"
+
+#include "function_boilerplate.h"
+
 FUNCTION_BEGIN(FunctionComposeTriple,0,3,false,0)
   
   //! Evaluate function.
