@@ -24,6 +24,10 @@
 #ifndef _function_constant_h_
 #define _function_constant_h_
 
+#include "common.h"
+
+#include "function_boilerplate.h"
+
 //------------------------------------------------------------------------------------------
 
 //! Function class representing a constant value.
