@@ -27,6 +27,10 @@
 #ifndef _function_top_h_
 #define _function_top_h_
 
+#include "common.h"
+
+#include "function_boilerplate.h"
+
 class Transform;
 
 //! Function intended primarily to be the top level function node.
@@ -36,7 +40,7 @@ FUNCTION_BEGIN(FunctionTop,24,1,false,0)
 
 public:
   //! This returns a random tree suitable for use as a starting image.
-  static std::auto_ptr<FunctionTop> initial(const MutationParameters& parameters,const FunctionRegistration* specific_fn=0,bool unwrapped=false);
+  static std::unique_ptr<FunctionTop> initial(const MutationParameters& parameters,const FunctionRegistration* specific_fn=0,bool unwrapped=false);
 
   virtual const XYZ evaluate(const XYZ& p) const;
 
