@@ -23,7 +23,11 @@
 
 #ifndef _function_transform_h_
 #define _function_transform_h_
- 
+
+#include "common.h"
+
+#include "function_boilerplate.h"
+
 #include "transform.h"
 
 //------------------------------------------------------------------------------------------
