@@ -24,6 +24,10 @@
 #ifndef _functions_quantize_h_
 #define _functions_quantize_h_
 
+#include "common.h"
+
+#include "function_boilerplate.h"
+
 #include "hex.h"
 
 //------------------------------------------------------------------------------------------
