@@ -24,6 +24,10 @@
 #ifndef _xyz_h_
 #define _xyz_h_
 
+#include "common.h"
+
+#include "xy.h"
+
 class Random01;
 
 //! Class to hold vectors in 3D cartesian co-ordinates.
